Name: gssklog
Version: 0.11
Release: 1
Summary: Client and Daemon to get/issue AFS tokens based on GSI credentials
Copyright: Modified BSD with some components MIT and some IBM
Group: System Environment/Daemons
Source: ftp://achilles.ctd.anl.gov/pub/DEE/%{name}-%{version}.tar
Patch0: gssklogd.SMcKee.patch
URL: ftp://achilles.ctd.anl.gov/pub/DEE
Packager: Mike Jones <mike.jones@manchester.ac.uk>
#Requires: vdt_globus_sdk
#%define GLOBUS_LOCATION %(echo $GLOBUS_LOCATION |sed -e 's/\\\///')
#BuildRequires: openafs-server,/%GLOBUS_LOCATION/lib/libglobus_gssapi_gsi_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_gsi_credential_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_gsi_callback_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_gsi_proxy_core_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_gsi_cert_utils_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_common_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_gsi_sysconfig_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_proxy_ssl_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_openssl_error_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_oldgaa_gcc32.a,/%GLOBUS_LOCATION/lib/libglobus_openssl_gcc32.a,/%GLOBUS_LOCATION/lib/libssl_gcc32.a,/%GLOBUS_LOCATION/lib/libcrypto_gcc32.a
BuildRequires: openafs-server

%description
GSS klog server and client compiled to link against GSI libraries in GT2.2+

A Server to allow one to obtain an AFS token, using a Generic Security Services
(GSS) implementation for authentication thus giving the user and administrators
greater flexibility in authenticating to an AFS cell. This can still be used in 
conjunction with current AFS authentication methods. This separates the dependency
of AFS on using Kerberos V4 tickets to obtain a token.

A modified klog client program (gssklog) uses the GSS to authenticate to a daemon 
process running on one or more of the AFS database servers. If authentication is 
accepted, and the user is found in a map file on the server, an AFS token is 
returned.

%package server
Summary: Daemon to issue AFS tokens to clients presenting GSI credentials
Group: System Environment/Daemons
Requires: openafs-server
%description server
Server to allow one to obtain an AFS token, using a Generic Security Services 
(GSS) implementation for authentication thus giving the user and administrators 
greater flexibility in authenticating to an AFS cell. This can still be used in 
conjunction with current AFS authentication methods. This separates the dependency 
of AFS on using Kerberos V4 tickets to obtain a token.

%package client
Summary: Client to obtain AFS tokens using a GSI credential
Group: Applications/Internet
Requires: openafs-client

%description client
A modified klog program uses the GSS to authenticate to a daemon process running
on one or more of the AFS database servers. If authentication is accepted, and the
user is found in a map file on the server, an AFS token is returned.

%prep

%setup
%patch0 -p1 -b .gssklogd.smckee 

%build
if [ "${GLOBUS_LOCATION}" -a -d ${GLOBUS_LOCATION} ]
then
  echo "Globus Location = ${GLOBUS_LOCATION}"
else
  for GL in /opt/globus /opt/vdt/globus /usr/local/globus /usr/lib/globus
  do
    [ -d ${GL} ] && GLOBUS_LOCATION=$GL && break
  done
fi

if [ "${GLOBUS_LOCATION}" = "" -o ! -d ${GLOBUS_LOCATION} ]
then
  echo " ****cannot find Globus**** try setting GLOBUS_LOCATION"
  exit 1
fi

for flavour in `ls ${GLOBUS_LOCATION}/lib/libglobus_common_* | sed -e 's/.*\/libglobus_common_//' -e 's/\..*//'|sort -r|uniq 2>/dev/null`
do
  [ "$flavour" = "gcc32dbg" ] && break
done

export GLOBUS_LOCATION
./configure --with-afs=/usr --with-ccopts=-DDEFAULT_PORT=750 --with-gss-lib-dir=${GLOBUS_LOCATION}/lib --with-static=gsi22 --enable-server --with-tcp-wrappers=/afs/anl.gov/appl/wrapper-7.6/@sys --enable-pam --with-flavor=${flavour}
make

%install 
/usr/bin/install -c -s gssklogd /usr/local/sbin/gssklogd
/usr/bin/install -c -s gssklog /usr/local/bin/gssklog
/usr/bin/install -c -s pam_gssklog.so.1 /usr/local/lib/pam_gssklog.so.1

%post client
ln -s pam_gssklog.so.1 /usr/local/lib/pam_gssklog.so

%post server
if test -e /etc/rc.d/init.d/gssklogd
then
  mv /etc/rc.d/init.d/gssklogd /etc/rc.d/init.d/gssklogd.installold
fi
cat <<+ >/etc/rc.d/init.d/gssklogd
#!/bin/bash
# chkconfig: 35 99 01

# source function library
. /etc/rc.d/init.d/functions

#Set up globus locations - not needed we made static (globus) links
#export GLOBUS_LOCATION=/opt/globus
#export LD_LIBRARY_PATH=/opt/globus/lib\${LD_LIBRARY_PATH:+":"}\$LD_LIBRARY_PATH

PID_FILE=/var/run/gsiklogd.pid
LOCKFILE=/var/lock/subsys/gsiklogd
RETVAL=0
prog=gssklogd
GSIKLOGD=/usr/local/sbin/gssklogd

start()
{
        echo -n "Starting \$prog:"
        daemon \$GSIKLOGD && success || failure
        RETVAL=\$?
        [ "\$RETVAL" = 0 ] && touch \$LOCKFILE
        echo
}

stop()
{
        echo -n "Stopping \$prog:"
        killproc \$GSIKLOGD -TERM
        RETVAL=\$?
        [ "\$RETVAL" = 0 ] && rm -f \$LOCKFILE
        echo
}

case "\$1" in
        start)
                start
                ;;
        stop)
                stop
                ;;
        restart)
                stop
                start
                ;;
        reload)
                reload
                ;;
        condrestart)
                if [ -f /var/lock/subsys/sshd ] ; then
                        do_restart_sanity_check
                        if [ "\$RETVAL" = 0 ] ; then
                                stop
                                # avoid race
                                sleep 3
                                start
                        fi
                fi
                ;;
        status)
                status \$GSSKLOGD
                RETVAL=\$?
                ;;
        *)
                echo \$"Usage: \$0 {start|stop|restart|reload|condrestart|status}"                RETVAL=1
esac
exit \$RETVAL
+
chmod 0755 /etc/rc.d/init.d/gssklogd
ln -s /etc/rc.d/init.d/gssklogd /etc/rc.d/rc3.d/S99gssklogd
ln -s /etc/rc.d/init.d/gssklogd /etc/rc.d/rc5.d/S99gssklogd
ln -s /etc/rc.d/init.d/gssklogd /etc/rc.d/rc3.d/K01gssklogd
ln -s /etc/rc.d/init.d/gssklogd /etc/rc.d/rc5.d/K01gssklogd
touch /etc/grid-security/afsgrid-mapfile

%postun server
rm -f /etc/rc.d/init.d/gssklogd /etc/rc.d/rc3.d/S99gssklogd /etc/rc.d/rc5.d/S99gssklogd /etc/rc.d/rc3.d/K01gssklogd /etc/rc.d/rc5.d/K01gssklogd

%files client
%attr(0755, root, root) /usr/local/bin/gssklog
%attr(0755, root, root) /usr/local/lib/pam_gssklog.so.1
%doc README

%files server
%attr(0755, root, root) /usr/local/sbin/gssklogd
%doc README
